# -*- coding: utf-8 -*-

__title__ = 'qjson'
__version__ = '0.1.3'
__author__ = 'Jerry Chou'
__license__ = 'MIT License'

from .qjson import loads